TryReserveErrorKind

Enum TryReserveErrorKind 

pub enum TryReserveErrorKind {
    CapacityOverflow,
    AllocError {
        layout: Layout,
        non_exhaustive: (),
    },
}
Details of the allocation that caused a TryReserveError.

Variants



CapacityOverflow

Error due to the computed capacity exceeding the collection’s maximum (usually isize::MAX bytes).



AllocError

The memory allocator returned an error

Fields

layout: Layout

The layout of allocation request that failed

non_exhaustive: ()

Reserved field for future compatibility with the standard library. This aligns with an RFC for future allocator error handling: https://github.com/rust-lang/wg-allocators/issues/23